==> eam-wshub-proxyclient-11.4-9-sources.jar: net/datastream/schemas/mp_fields/RFQSERVICEDETAILS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour RFQSERVICEDETAILS_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="RFQSERVICEDETAILS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RFQLINEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RFQWORKORDERACTIVITY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RFQPROJECTBUDGET" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELATEDWORKORDERID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MULTIEQUIP" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TASKSID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRADEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DELIVERYADDRESSID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DUEDATE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGCURRENCY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}JOBSEQUENCE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}JOBPLANID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RFQSERVICEDETAILS_Type", propOrder = {
    "rfqlineid",
    "type",
    "rfqworkorderactivity",
    "rfqprojectbudget",
    "equipmentid",
    "relatedworkorderid",
    "multiequip",
    "tasksid",
    "tradeid",
    "departmentid",
    "deliveryaddressid",
    "duedate",
    "orgcurrency",
    "jobsequence",
    "jobplanid"
})
public class RFQSERVICEDETAILS_Type {

    @XmlElement(name = "RFQLINEID", required = true)
    protected RFQLINEID_Type rfqlineid;
    @XmlElement(name = "TYPE", required = true)
    protected TYPE_Type type;
    @XmlElement(name = "RFQWORKORDERACTIVITY")
    protected RFQWORKORDERACTIVITY rfqworkorderactivity;
    @XmlElement(name = "RFQPROJECTBUDGET")
    protected RFQPROJECTBUDGET_Type rfqprojectbudget;
    @XmlElement(name = "EQUIPMENTID")
    protected EQUIPMENTID_Type equipmentid;
    @XmlElement(name = "RELATEDWORKORDERID")
    protected WOID_Type relatedworkorderid;
    @XmlElement(name = "MULTIEQUIP")
    protected String multiequip;
    @XmlElement(name = "TASKSID")
    protected TASKS_Type tasksid;
    @XmlElement(name = "TRADEID")
    protected TRADEID_Type tradeid;
    @XmlElement(name = "DEPARTMENTID")
    protected DEPARTMENTID_Type departmentid;
    @XmlElement(name = "DELIVERYADDRESSID")
    protected DELIVERYADDRESS_Type deliveryaddressid;
    @XmlElement(name = "DUEDATE", required = true)
    protected DATETIME duedate;
    @XmlElement(name = "ORGCURRENCY", required = true)
    protected CURRENCYID_Type orgcurrency;
    @XmlElement(name = "JOBSEQUENCE")
    protected Long jobsequence;
    @XmlElement(name = "JOBPLANID")
    protected TASKLISTID_Type jobplanid;

    /**
     * Obtient la valeur de la propriété rfqlineid.
     * 
     * @return
     *     possible object is
     *     {@link RFQLINEID_Type }
     *     
     */
    public RFQLINEID_Type getRFQLINEID() {
        return rfqlineid;
    }

    /**
     * Définit la valeur de la propriété rfqlineid.
     * 
     * @param value
     *     allowed object is
     *     {@link RFQLINEID_Type }
     *     
     */
    public void setRFQLINEID(RFQLINEID_Type value) {
        this.rfqlineid = value;
    }

    /**
     * Obtient la valeur de la propriété type.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getTYPE() {
        return type;
    }

    /**
     * Définit la valeur de la propriété type.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setTYPE(TYPE_Type value) {
        this.type = value;
    }

    /**
     * Obtient la valeur de la propriété rfqworkorderactivity.
     * 
     * @return
     *     possible object is
     *     {@link RFQWORKORDERACTIVITY }
     *     
     */
    public RFQWORKORDERACTIVITY getRFQWORKORDERACTIVITY() {
        return rfqworkorderactivity;
    }

    /**
     * Définit la valeur de la propriété rfqworkorderactivity.
     * 
     * @param value
     *     allowed object is
     *     {@link RFQWORKORDERACTIVITY }
     *     
     */
    public void setRFQWORKORDERACTIVITY(RFQWORKORDERACTIVITY value) {
        this.rfqworkorderactivity = value;
    }

    /**
     * Obtient la valeur de la propriété rfqprojectbudget.
     * 
     * @return
     *     possible object is
     *     {@link RFQPROJECTBUDGET_Type }
     *     
     */
    public RFQPROJECTBUDGET_Type getRFQPROJECTBUDGET() {
        return rfqprojectbudget;
    }

    /**
     * Définit la valeur de la propriété rfqprojectbudget.
     * 
     * @param value
     *     allowed object is
     *     {@link RFQPROJECTBUDGET_Type }
     *     
     */
    public void setRFQPROJECTBUDGET(RFQPROJECTBUDGET_Type value) {
        this.rfqprojectbudget = value;
    }

    /**
     * Obtient la valeur de la propriété equipmentid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getEQUIPMENTID() {
        return equipmentid;
    }

    /**
     * Définit la valeur de la propriété equipmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setEQUIPMENTID(EQUIPMENTID_Type value) {
        this.equipmentid = value;
    }

    /**
     * Obtient la valeur de la propriété relatedworkorderid.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getRELATEDWORKORDERID() {
        return relatedworkorderid;
    }

    /**
     * Définit la valeur de la propriété relatedworkorderid.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setRELATEDWORKORDERID(WOID_Type value) {
        this.relatedworkorderid = value;
    }

    /**
     * Obtient la valeur de la propriété multiequip.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMULTIEQUIP() {
        return multiequip;
    }

    /**
     * Définit la valeur de la propriété multiequip.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMULTIEQUIP(String value) {
        this.multiequip = value;
    }

    /**
     * Obtient la valeur de la propriété tasksid.
     * 
     * @return
     *     possible object is
     *     {@link TASKS_Type }
     *     
     */
    public TASKS_Type getTASKSID() {
        return tasksid;
    }

    /**
     * Définit la valeur de la propriété tasksid.
     * 
     * @param value
     *     allowed object is
     *     {@link TASKS_Type }
     *     
     */
    public void setTASKSID(TASKS_Type value) {
        this.tasksid = value;
    }

    /**
     * Obtient la valeur de la propriété tradeid.
     * 
     * @return
     *     possible object is
     *     {@link TRADEID_Type }
     *     
     */
    public TRADEID_Type getTRADEID() {
        return tradeid;
    }

    /**
     * Définit la valeur de la propriété tradeid.
     * 
     * @param value
     *     allowed object is
     *     {@link TRADEID_Type }
     *     
     */
    public void setTRADEID(TRADEID_Type value) {
        this.tradeid = value;
    }

    /**
     * Obtient la valeur de la propriété departmentid.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Définit la valeur de la propriété departmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

    /**
     * Obtient la valeur de la propriété deliveryaddressid.
     * 
     * @return
     *     possible object is
     *     {@link DELIVERYADDRESS_Type }
     *     
     */
    public DELIVERYADDRESS_Type getDELIVERYADDRESSID() {
        return deliveryaddressid;
    }

    /**
     * Définit la valeur de la propriété deliveryaddressid.
     * 
     * @param value
     *     allowed object is
     *     {@link DELIVERYADDRESS_Type }
     *     
     */
    public void setDELIVERYADDRESSID(DELIVERYADDRESS_Type value) {
        this.deliveryaddressid = value;
    }

    /**
     * Obtient la valeur de la propriété duedate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDUEDATE() {
        return duedate;
    }

    /**
     * Définit la valeur de la propriété duedate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDUEDATE(DATETIME value) {
        this.duedate = value;
    }

    /**
     * Obtient la valeur de la propriété orgcurrency.
     * 
     * @return
     *     possible object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public CURRENCYID_Type getORGCURRENCY() {
        return orgcurrency;
    }

    /**
     * Définit la valeur de la propriété orgcurrency.
     * 
     * @param value
     *     allowed object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public void setORGCURRENCY(CURRENCYID_Type value) {
        this.orgcurrency = value;
    }

    /**
     * Obtient la valeur de la propriété jobsequence.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getJOBSEQUENCE() {
        return jobsequence;
    }

    /**
     * Définit la valeur de la propriété jobsequence.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setJOBSEQUENCE(Long value) {
        this.jobsequence = value;
    }

    /**
     * Obtient la valeur de la propriété jobplanid.
     * 
     * @return
     *     possible object is
     *     {@link TASKLISTID_Type }
     *     
     */
    public TASKLISTID_Type getJOBPLANID() {
        return jobplanid;
    }

    /**
     * Définit la valeur de la propriété jobplanid.
     * 
     * @param value
     *     allowed object is
     *     {@link TASKLISTID_Type }
     *     
     */
    public void setJOBPLANID(TASKLISTID_Type value) {
        this.jobplanid = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/RFQSERVICEDETAILS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for RFQSERVICEDETAILS_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="RFQSERVICEDETAILS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RFQLINEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RFQWORKORDERACTIVITY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RFQPROJECTBUDGET" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELATEDWORKORDERID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MULTIEQUIP" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TASKSID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRADEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DELIVERYADDRESSID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DUEDATE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGCURRENCY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}JOBSEQUENCE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}JOBPLANID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RFQSERVICEDETAILS_Type", propOrder = {
    "rfqlineid",
    "type",
    "rfqworkorderactivity",
    "rfqprojectbudget",
    "equipmentid",
    "relatedworkorderid",
    "multiequip",
    "tasksid",
    "tradeid",
    "departmentid",
    "deliveryaddressid",
    "duedate",
    "orgcurrency",
    "jobsequence",
    "jobplanid"
})
public class RFQSERVICEDETAILS_Type {

    @XmlElement(name = "RFQLINEID", required = true)
    protected RFQLINEID_Type rfqlineid;
    @XmlElement(name = "TYPE", required = true)
    protected TYPE_Type type;
    @XmlElement(name = "RFQWORKORDERACTIVITY")
    protected RFQWORKORDERACTIVITY rfqworkorderactivity;
    @XmlElement(name = "RFQPROJECTBUDGET")
    protected RFQPROJECTBUDGET_Type rfqprojectbudget;
    @XmlElement(name = "EQUIPMENTID")
    protected EQUIPMENTID_Type equipmentid;
    @XmlElement(name = "RELATEDWORKORDERID")
    protected WOID_Type relatedworkorderid;
    @XmlElement(name = "MULTIEQUIP")
    protected String multiequip;
    @XmlElement(name = "TASKSID")
    protected TASKS_Type tasksid;
    @XmlElement(name = "TRADEID")
    protected TRADEID_Type tradeid;
    @XmlElement(name = "DEPARTMENTID")
    protected DEPARTMENTID_Type departmentid;
    @XmlElement(name = "DELIVERYADDRESSID")
    protected DELIVERYADDRESS_Type deliveryaddressid;
    @XmlElement(name = "DUEDATE", required = true)
    protected DATETIME duedate;
    @XmlElement(name = "ORGCURRENCY", required = true)
    protected CURRENCYID_Type orgcurrency;
    @XmlElement(name = "JOBSEQUENCE")
    protected Long jobsequence;
    @XmlElement(name = "JOBPLANID")
    protected TASKLISTID_Type jobplanid;

    /**
     * Gets the value of the rfqlineid property.
     * 
     * @return
     *     possible object is
     *     {@link RFQLINEID_Type }
     *     
     */
    public RFQLINEID_Type getRFQLINEID() {
        return rfqlineid;
    }

    /**
     * Sets the value of the rfqlineid property.
     * 
     * @param value
     *     allowed object is
     *     {@link RFQLINEID_Type }
     *     
     */
    public void setRFQLINEID(RFQLINEID_Type value) {
        this.rfqlineid = value;
    }

    /**
     * Gets the value of the type property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getTYPE() {
        return type;
    }

    /**
     * Sets the value of the type property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setTYPE(TYPE_Type value) {
        this.type = value;
    }

    /**
     * Gets the value of the rfqworkorderactivity property.
     * 
     * @return
     *     possible object is
     *     {@link RFQWORKORDERACTIVITY }
     *     
     */
    public RFQWORKORDERACTIVITY getRFQWORKORDERACTIVITY() {
        return rfqworkorderactivity;
    }

    /**
     * Sets the value of the rfqworkorderactivity property.
     * 
     * @param value
     *     allowed object is
     *     {@link RFQWORKORDERACTIVITY }
     *     
     */
    public void setRFQWORKORDERACTIVITY(RFQWORKORDERACTIVITY value) {
        this.rfqworkorderactivity = value;
    }

    /**
     * Gets the value of the rfqprojectbudget property.
     * 
     * @return
     *     possible object is
     *     {@link RFQPROJECTBUDGET_Type }
     *     
     */
    public RFQPROJECTBUDGET_Type getRFQPROJECTBUDGET() {
        return rfqprojectbudget;
    }

    /**
     * Sets the value of the rfqprojectbudget property.
     * 
     * @param value
     *     allowed object is
     *     {@link RFQPROJECTBUDGET_Type }
     *     
     */
    public void setRFQPROJECTBUDGET(RFQPROJECTBUDGET_Type value) {
        this.rfqprojectbudget = value;
    }

    /**
     * Gets the value of the equipmentid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getEQUIPMENTID() {
        return equipmentid;
    }

    /**
     * Sets the value of the equipmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setEQUIPMENTID(EQUIPMENTID_Type value) {
        this.equipmentid = value;
    }

    /**
     * Gets the value of the relatedworkorderid property.
     * 
     * @return
     *     possible object is
     *     {@link WOID_Type }
     *     
     */
    public WOID_Type getRELATEDWORKORDERID() {
        return relatedworkorderid;
    }

    /**
     * Sets the value of the relatedworkorderid property.
     * 
     * @param value
     *     allowed object is
     *     {@link WOID_Type }
     *     
     */
    public void setRELATEDWORKORDERID(WOID_Type value) {
        this.relatedworkorderid = value;
    }

    /**
     * Gets the value of the multiequip property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMULTIEQUIP() {
        return multiequip;
    }

    /**
     * Sets the value of the multiequip property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMULTIEQUIP(String value) {
        this.multiequip = value;
    }

    /**
     * Gets the value of the tasksid property.
     * 
     * @return
     *     possible object is
     *     {@link TASKS_Type }
     *     
     */
    public TASKS_Type getTASKSID() {
        return tasksid;
    }

    /**
     * Sets the value of the tasksid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TASKS_Type }
     *     
     */
    public void setTASKSID(TASKS_Type value) {
        this.tasksid = value;
    }

    /**
     * Gets the value of the tradeid property.
     * 
     * @return
     *     possible object is
     *     {@link TRADEID_Type }
     *     
     */
    public TRADEID_Type getTRADEID() {
        return tradeid;
    }

    /**
     * Sets the value of the tradeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TRADEID_Type }
     *     
     */
    public void setTRADEID(TRADEID_Type value) {
        this.tradeid = value;
    }

    /**
     * Gets the value of the departmentid property.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Sets the value of the departmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

    /**
     * Gets the value of the deliveryaddressid property.
     * 
     * @return
     *     possible object is
     *     {@link DELIVERYADDRESS_Type }
     *     
     */
    public DELIVERYADDRESS_Type getDELIVERYADDRESSID() {
        return deliveryaddressid;
    }

    /**
     * Sets the value of the deliveryaddressid property.
     * 
     * @param value
     *     allowed object is
     *     {@link DELIVERYADDRESS_Type }
     *     
     */
    public void setDELIVERYADDRESSID(DELIVERYADDRESS_Type value) {
        this.deliveryaddressid = value;
    }

    /**
     * Gets the value of the duedate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDUEDATE() {
        return duedate;
    }

    /**
     * Sets the value of the duedate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDUEDATE(DATETIME value) {
        this.duedate = value;
    }

    /**
     * Gets the value of the orgcurrency property.
     * 
     * @return
     *     possible object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public CURRENCYID_Type getORGCURRENCY() {
        return orgcurrency;
    }

    /**
     * Sets the value of the orgcurrency property.
     * 
     * @param value
     *     allowed object is
     *     {@link CURRENCYID_Type }
     *     
     */
    public void setORGCURRENCY(CURRENCYID_Type value) {
        this.orgcurrency = value;
    }

    /**
     * Gets the value of the jobsequence property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getJOBSEQUENCE() {
        return jobsequence;
    }

    /**
     * Sets the value of the jobsequence property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setJOBSEQUENCE(Long value) {
        this.jobsequence = value;
    }

    /**
     * Gets the value of the jobplanid property.
     * 
     * @return
     *     possible object is
     *     {@link TASKLISTID_Type }
     *     
     */
    public TASKLISTID_Type getJOBPLANID() {
        return jobplanid;
    }

    /**
     * Sets the value of the jobplanid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TASKLISTID_Type }
     *     
     */
    public void setJOBPLANID(TASKLISTID_Type value) {
        this.jobplanid = value;
    }

}
